# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
from .identifier_list import IdentifierList


class Rule_Approver(pydantic_v1.BaseModel):
    """
    Examples
    --------
    from mercoa import IdentifierList_RolesList, Rule_Approver

    Rule_Approver(
        num_approvers=2,
        identifier_list=IdentifierList_RolesList(value=["Admin", "Controller"]),
    )
    """

    num_approvers: int = pydantic_v1.Field(alias="numApprovers")
    identifier_list: IdentifierList = pydantic_v1.Field(alias="identifierList")
    type: typing.Literal["approver"] = "approver"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


"""
from mercoa import IdentifierList_RolesList, Rule_Approver

Rule_Approver(
    num_approvers=2,
    identifier_list=IdentifierList_RolesList(value=["Admin", "Controller"]),
)
"""
Rule = Rule_Approver
